#[repr(u8)]pub enum Imb {
IMB_0 = 0,
IMB_1 = 1,
}Variants
IMB_0 = 0
If ESR2[VPS] is asserted, the ESR2[LPTM] is not an inactive Mailbox.
IMB_1 = 1
If ESR2[VPS] is asserted, there is at least one inactive Mailbox. LPTM content is the number of the first one.
Implementations